Index: /trunk/psLib/test/astro/verified/tst_psCoord.stderr
===================================================================
--- /trunk/psLib/test/astro/verified/tst_psCoord.stderr	(revision 5548)
+++ /trunk/psLib/test/astro/verified/tst_psCoord.stderr	(revision 5549)
@@ -6,9 +6,9 @@
 
 <HOST>|I|testPlaneTransformAlloc
-    Following should generate an error message: negative x terms
+    Following should generate an error message: negative x order
 <HOST>|E|psPlaneTransformAlloc (FILE:LINENO)
     Error: n1 is less than 0.
 <HOST>|I|testPlaneTransformAlloc
-    Following should generate an error message: negative y terms
+    Following should generate an error message: negative y order
 <HOST>|E|psPlaneTransformAlloc (FILE:LINENO)
     Error: n2 is less than 0.
@@ -23,17 +23,17 @@
 
 <HOST>|I|testPlaneDistortAlloc
-    Following should generate an error message for negative x term
+    Following should generate an error message for negative x order
 <HOST>|E|psPlaneDistortAlloc (FILE:LINENO)
     Error: n1 is less than 0.
 <HOST>|I|testPlaneDistortAlloc
-    Following should generate an error message for negative y term
+    Following should generate an error message for negative y order
 <HOST>|E|psPlaneDistortAlloc (FILE:LINENO)
     Error: n2 is less than 0.
 <HOST>|I|testPlaneDistortAlloc
-    Following should generate an error message for negative z term
+    Following should generate an error message for negative z order
 <HOST>|E|psPlaneDistortAlloc (FILE:LINENO)
     Error: n3 is less than 0.
 <HOST>|I|testPlaneDistortAlloc
-    Following should generate an error message for negative w term
+    Following should generate an error message for negative w order
 <HOST>|E|psPlaneDistortAlloc (FILE:LINENO)
     Error: n4 is less than 0.

Index: /trunk/psLib/test/astro/tst_psCoord.c
===================================================================
--- /trunk/psLib/test/astro/tst_psCoord.c	(revision 5548)
+++ /trunk/psLib/test/astro/tst_psCoord.c	(revision 5549)
@@ -6,6 +6,6 @@
 *  @author GLG, MHPCC
 *
-*  @version $Revision: 1.6 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2005-10-12 21:02:20 $
+*  @version $Revision: 1.7 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2005-11-18 21:23:21 $
 *
 *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -35,13 +35,13 @@
 }
 
-#define NX_TERMS 2
-#define NY_TERMS 3
-#define NZ_TERMS 4
-#define NT_TERMS 5
+#define ORDER_X 2
+#define ORDER_Y 3
+#define ORDER_Z 4
+#define ORDER_T 5
 
 psS32 testPlaneTransformAlloc( void )
 {
     // Allocate psPlaneTransform with known x and y terms
-    psPlaneTransform *myPT = psPlaneTransformAlloc(NX_TERMS, NY_TERMS);
+    psPlaneTransform *myPT = psPlaneTransformAlloc(ORDER_X, ORDER_Y);
 
     // Verify returned value is not NULL
@@ -52,22 +52,22 @@
 
     // Verify returned transform has members set properly
-    if ((1 + myPT->x->nX) != NX_TERMS) {
+    if (myPT->x->nX != ORDER_X) {
         psError(PS_ERR_UNKNOWN,true,"myPT->x->nX is %d, should be %d",
-                myPT->x->nX, NX_TERMS-1);
+                myPT->x->nX, ORDER_X);
         return 2;
     }
-    if ((1 + myPT->y->nX) != NX_TERMS) {
+    if (myPT->y->nX != ORDER_X) {
         psError(PS_ERR_UNKNOWN,true,"myPT->y->nX is %d, should be %d",
-                myPT->y->nX, NX_TERMS-1);
+                myPT->y->nX, ORDER_X);
         return 3;
     }
-    if ((1 + myPT->x->nY) != NY_TERMS) {
+    if (myPT->x->nY != ORDER_Y) {
         psError(PS_ERR_UNKNOWN,true,"myPT->x->nY is %d, should be %d",
-                myPT->x->nY, NY_TERMS-1);
+                myPT->x->nY, ORDER_Y);
         return 4;
     }
-    if ((1 + myPT->y->nY) != NY_TERMS) {
+    if (myPT->y->nY != ORDER_Y) {
         psError(PS_ERR_UNKNOWN,true,"myPT->y->nY is %d, should be %d",
-                myPT->y->nY, NY_TERMS-1);
+                myPT->y->nY, ORDER_Y);
         return 5;
     }
@@ -76,7 +76,7 @@
     psFree(myPT);
 
-    // Attempt to specify negative x terms and verify NULL returned and errror message generated
-    psLogMsg(__func__,PS_LOG_INFO,"Following should generate an error message: negative x terms");
-    myPT = psPlaneTransformAlloc(-1.0, 1.0);
+    // Attempt to specify negative x order and verify NULL returned and errror message generated
+    psLogMsg(__func__,PS_LOG_INFO,"Following should generate an error message: negative x order");
+    myPT = psPlaneTransformAlloc(-1, 1);
     if (myPT != NULL) {
         psError(PS_ERR_UNKNOWN,true,"psPlaneTransformAlloc() did not return NULL.");
@@ -84,7 +84,7 @@
     }
 
-    // Attempt to specify negative y terms and verify NULL returned and error message generated
-    psLogMsg(__func__,PS_LOG_INFO,"Following should generate an error message: negative y terms");
-    myPT = psPlaneTransformAlloc(1.0, -1.0);
+    // Attempt to specify negative y order and verify NULL returned and error message generated
+    psLogMsg(__func__,PS_LOG_INFO,"Following should generate an error message: negative y order");
+    myPT = psPlaneTransformAlloc(1, -1);
     if (myPT != NULL) {
         psError(PS_ERR_UNKNOWN,true,"psPlaneTransformAlloc() did not return NULL.");
@@ -101,5 +101,5 @@
 {
     // Invoke function with known parameters
-    psPlaneDistort *myPD = psPlaneDistortAlloc(NX_TERMS, NY_TERMS, NZ_TERMS, NT_TERMS);
+    psPlaneDistort *myPD = psPlaneDistortAlloc(ORDER_X, ORDER_Y, ORDER_Z, ORDER_T);
 
     // Verify NULL is not returned
@@ -109,42 +109,42 @@
     }
     // Verify the terms are properly set after allocation
-    if ((1 + myPD->x->nX) != NX_TERMS) {
+    if (myPD->x->nX != ORDER_X) {
         psError(PS_ERR_UNKNOWN,true,"myPD->x->nX is %d, should be %d",
-                myPD->x->nX, NX_TERMS-1);
+                myPD->x->nX, ORDER_X);
         return 2;
     }
-    if ((1 + myPD->y->nX) != NX_TERMS) {
+    if (myPD->y->nX != ORDER_X) {
         psError(PS_ERR_UNKNOWN,true,"myPD->y->nX is %d, should be %d",
-                myPD->y->nX, NX_TERMS-1);
+                myPD->y->nX, ORDER_X);
         return 3;
     }
-    if ((1 + myPD->x->nY) != NY_TERMS) {
+    if (myPD->x->nY != ORDER_Y) {
         psError(PS_ERR_UNKNOWN,true,"myPD->x->nY is %d, should be %d",
-                myPD->x->nY, NY_TERMS-1);
+                myPD->x->nY, ORDER_Y);
         return 4;
     }
-    if ((1 + myPD->y->nY) != NY_TERMS) {
+    if (myPD->y->nY != ORDER_Y) {
         psError(PS_ERR_UNKNOWN,true,"myPD->y->nY is %d, should be %d",
-                myPD->y->nY, NY_TERMS-1);
+                myPD->y->nY, ORDER_Y);
         return 5;
     }
-    if ((1 + myPD->x->nZ) != NZ_TERMS) {
+    if (myPD->x->nZ != ORDER_Z) {
         psError(PS_ERR_UNKNOWN,true,"myPD->x->nZ is %d, should be %d",
-                myPD->x->nX, NZ_TERMS-1);
+                myPD->x->nZ, ORDER_Z);
         return 6;
     }
-    if ((1 + myPD->y->nZ) != NZ_TERMS) {
+    if (myPD->y->nZ != ORDER_Z) {
         psError(PS_ERR_UNKNOWN,true,"myPD->y->nZ is %d, should be %d",
-                myPD->y->nZ, NZ_TERMS-1);
+                myPD->y->nZ, ORDER_Z);
         return 7;
     }
-    if ((1 + myPD->x->nT) != NT_TERMS) {
+    if (myPD->x->nT != ORDER_T) {
         psError(PS_ERR_UNKNOWN,true,"myPD->x->nT is %d, should be %d",
-                myPD->x->nT, NT_TERMS-1);
+                myPD->x->nT, ORDER_T);
         return 8;
     }
-    if ((1 + myPD->y->nT) != NT_TERMS) {
+    if (myPD->y->nT != ORDER_T) {
         psError(PS_ERR_UNKNOWN,true,"myPD->y->nT is %d, should be %d",
-                myPD->y->nT, NT_TERMS-1);
+                myPD->y->nT, ORDER_T);
         return 9;
     }
@@ -152,7 +152,7 @@
     psFree(myPD);
 
-    // Invoke function with negative x term parameter
-    psLogMsg(__func__,PS_LOG_INFO,"Following should generate an error message for negative x term");
-    myPD = psPlaneDistortAlloc(-1.0, 1.0, 1.0, 1.0);
+    // Invoke function with negative x order parameter
+    psLogMsg(__func__,PS_LOG_INFO,"Following should generate an error message for negative x order");
+    myPD = psPlaneDistortAlloc(-1, 1, 1, 1);
     if (myPD != NULL) {
         psError(PS_ERR_UNKNOWN,true,"psPlaneDistortAlloc() did not return NULL.");
@@ -160,7 +160,7 @@
     }
 
-    // Invoke function with negative y term parameter
-    psLogMsg(__func__,PS_LOG_INFO,"Following should generate an error message for negative y term");
-    myPD = psPlaneDistortAlloc(1.0, -1.0, 1.0, 1.0);
+    // Invoke function with negative y order parameter
+    psLogMsg(__func__,PS_LOG_INFO,"Following should generate an error message for negative y order");
+    myPD = psPlaneDistortAlloc(1, -1, 1, 1);
     if (myPD != NULL) {
         psError(PS_ERR_UNKNOWN,true,"psPlaneDistortAlloc() did not return NULL.");
@@ -168,7 +168,7 @@
     }
 
-    // Invoke function with negative z term parameter
-    psLogMsg(__func__,PS_LOG_INFO,"Following should generate an error message for negative z term");
-    myPD = psPlaneDistortAlloc(1.0, 1.0, -1.0, 1.0);
+    // Invoke function with negative z order parameter
+    psLogMsg(__func__,PS_LOG_INFO,"Following should generate an error message for negative z order");
+    myPD = psPlaneDistortAlloc(1, 1, -1, 1);
     if (myPD != NULL) {
         psError(PS_ERR_UNKNOWN,true,"psPlaneDistortAlloc() did not return NULL.");
@@ -176,7 +176,7 @@
     }
 
-    // Invoke function with negative w term parameter
-    psLogMsg(__func__,PS_LOG_INFO,"Following should generate an error message for negative w term");
-    myPD = psPlaneDistortAlloc(1.0, 1.0, 1.0, -1.0);
+    // Invoke function with negative t order parameter
+    psLogMsg(__func__,PS_LOG_INFO,"Following should generate an error message for negative w order");
+    myPD = psPlaneDistortAlloc(1, 1, 1, -1);
     if (myPD != NULL) {
         psError(PS_ERR_UNKNOWN,true,"psPlaneDistortAlloc() did not return NULL.");